#
# spec file for package perl-Class-Data-Inheritable
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Class-Data-Inheritable
Name:           perl-Class-Data-Inheritable
Version:        0.09
Release:        1.14
Summary:        Inheritable, overridable class data
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RS/RSHERER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Class::Data::Inheritable is for creating accessor/mutators to class data.
That is, if you want to store something about your class as a whole
(instead of about a single object). This data is then inherited by your
subclasses and can be overridden.

For example:

  Pere::Ubu->mk_classdata('Suitcase');

will generate the method Suitcase() in the class Pere::Ubu.

This new method can be used to get and set a piece of class data.

  Pere::Ubu->Suitcase('Red');
  $suitcase = Pere::Ubu->Suitcase;

The interesting part happens when a class inherits from Pere::Ubu:

  package Raygun;
  use base qw(Pere::Ubu);
  
  # Raygun's suitcase is Red.
  $suitcase = Raygun->Suitcase;

Raygun inherits its Suitcase class data from Pere::Ubu.

Inheritance of class data works analogous to method inheritance. As long as
Raygun does not "override" its inherited class data (by using Suitcase() to
set a new value) it will continue to use whatever is set in Pere::Ubu and
inherit further changes:

  # Both Raygun's and Pere::Ubu's suitcases are now Blue
  Pere::Ubu->Suitcase('Blue');

However, should Raygun decide to set its own Suitcase() it has now
"overridden" Pere::Ubu and is on its own, just like if it had overridden a
method:

  # Raygun has an orange suitcase, Pere::Ubu's is still Blue.
  Raygun->Suitcase('Orange');

Now that Raygun has overridden Pere::Ubu further changes by Pere::Ubu no
longer effect Raygun.

  # Raygun still has an orange suitcase, but Pere::Ubu is using Samsonite.
  Pere::Ubu->Suitcase('Samsonite');

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes doc README

%changelog
* Sat Jul 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.09
  see /usr/share/doc/packages/perl-Class-Data-Inheritable/Changes
  0.09  Fri Jul 30 22:42:00 UTC 2021
  - Update spelling errors to resolve #83824 and #86563
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Nov 24 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
- noarch pkg
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Jan 28 2008 anicka@suse.cz
- update to 0.08
  * Fix 'perltooc' typo in Docs
  * Relicense as dual AL/GPL
* Wed Sep 20 2006 anicka@suse.cz
- update to 0.06
  * Sync the japanese docs
* Thu Sep 14 2006 anicka@suse.cz
- update to 0.05
  * Use correct bug reporting address (Jonathan Rockway)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan  3 2006 anicka@suse.cz
- update to 0.04
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Jul  7 2005 pth@suse.de
- Provide Class-Data-Inheritable
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Aug 13 2001 rvasice@suse.cz
- initial package release (version 0.02)
